@@ -1,8 +1,8 @@
-package Pcore::PgSQL v0.22.2;
+package Pcore::PgSQL v0.22.3;
 
 use Pcore -dist, -class;
 
-has data_dir => ( , required => 1 );    # Str
+has data_dir => ( required => 1 );    # Str
 
 sub run ( $self ) {
     my $db_dir = "$self->{data_dir}/db/";
